==> honeybee-energy-1.15.3.tar.gz: honeybee-energy-1.15.3/honeybee_energy/load/_base.py <==
# coding=utf-8
"""Base object for all load definitions."""
from __future__ import division

from ..schedule.ruleset import ScheduleRuleset
from ..schedule.fixedinterval import ScheduleFixedInterval

from honeybee._lockable import lockable
from honeybee.typing import valid_ep_string, tuple_with_length


@lockable
class _LoadBase(object):
    """A base object for all load definitions.

    Properties:
        * name
    """
    __slots__ = ('_name', '_locked')

    def __init__(self, name):
        """Initialize LoadBase.

        Args:
            name: Text string for the load definition name. Must be <= 100 characters.
                Can include spaces but special characters will be stripped out.
        """
        self._locked = False  # unlocked by default
        self.name = name

    @property
    def name(self):
        """Get or set the text string for object name."""
        return self._name

    @name.setter
    def name(self, name):
        self._name = valid_ep_string(name)

    def duplicate(self):
        """Get a copy of this object."""
        return self.__copy__()

    def _check_fractional_schedule_type(self, schedule, obj_name=''):
        """Check that the type limit of an input schedule is fractional."""
        if schedule.schedule_type_limit is not None:
            assert schedule.schedule_type_limit.unit == 'fraction', '{} schedule ' \
                'should be fractional [Dimensionless]. Got a schedule of unit_type ' \
                '[{}].'.format(obj_name, schedule.schedule_type_limit.unit_type)

    @staticmethod
    def _check_avg_weights(load_objects, weights, obj_name):
        """Check input weights of an average calculation and generate them if None."""
        if weights is None:
            weights = unity_weights = [1 / len(load_objects)] * len(load_objects) if \
                len(load_objects) > 0 else []
        else:
            weights = tuple_with_length(weights, len(load_objects), float,
                                        'average {} weights'.format(obj_name))
            total_weight = sum(weights)
            assert total_weight <= 1, 'Average {} weights must be less than or equal to' \
                ' 1. Got {}.'.format(obj_name, sum(weights))
            unity_weights = [w / total_weight for w in weights]

        return weights, unity_weights

    @staticmethod
    def _average_schedule(name, scheds, weights, timestep):
        """Average a set of schedules together (no matter their type)."""
        try:
            return ScheduleRuleset.average_schedules(name, scheds, weights, timestep)
        except AttributeError:
            return ScheduleFixedInterval.average_schedules(name, scheds, weights)

    @staticmethod
    def _get_schedule_from_dict(sch_dict):
        """Get a schedule object from a schedule dictionary."""
        if sch_dict['type'] == 'ScheduleRuleset':
            return ScheduleRuleset.from_dict(sch_dict)
        elif sch_dict['type'] == 'ScheduleFixedInterval':
            return ScheduleFixedInterval.from_dict(sch_dict)
        else:
            raise NotImplementedError(
                'Schedule {} is not supported.'.format(sch_dict['type']))

    def __copy__(self):
        return _LoadBase(self.name)

    def ToString(self):
        """Overwrite .NET ToString."""
        return self.__repr__()

    def __repr__(self):
        return 'Load Base:\n name: {}'.format(self.name)

==> honeybee-energy-1.32.0.tar.gz: honeybee-energy-1.32.0/honeybee_energy/load/_base.py <==
# coding=utf-8
"""Base object for all load definitions."""
from __future__ import division

from ..schedule.ruleset import ScheduleRuleset
from ..schedule.fixedinterval import ScheduleFixedInterval

from honeybee._lockable import lockable
from honeybee.typing import valid_ep_string, tuple_with_length


@lockable
class _LoadBase(object):
    """A base object for all load definitions.

    Args:
        name: Text string for the load definition name. Must be <= 100 characters.
            Can include spaces but special characters will be stripped out.

    Properties:
        * name
    """
    __slots__ = ('_name', '_locked')

    def __init__(self, name):
        """Initialize LoadBase."""
        self._locked = False  # unlocked by default
        self.name = name

    @property
    def name(self):
        """Get or set the text string for object name."""
        return self._name

    @name.setter
    def name(self, name):
        self._name = valid_ep_string(name)

    def duplicate(self):
        """Get a copy of this object."""
        return self.__copy__()

    def _check_fractional_schedule_type(self, schedule, obj_name=''):
        """Check that the type limit of an input schedule is fractional."""
        if schedule.schedule_type_limit is not None:
            assert schedule.schedule_type_limit.unit == 'fraction', '{} schedule ' \
                'should be fractional [Dimensionless]. Got a schedule of unit_type ' \
                '[{}].'.format(obj_name, schedule.schedule_type_limit.unit_type)

    @staticmethod
    def _check_avg_weights(load_objects, weights, obj_name):
        """Check input weights of an average calculation and generate them if None."""
        if weights is None:
            weights = unity_weights = [1 / len(load_objects)] * len(load_objects) if \
                len(load_objects) > 0 else []
        else:
            weights = tuple_with_length(weights, len(load_objects), float,
                                        'average {} weights'.format(obj_name))
            total_weight = sum(weights)
            assert total_weight <= 1 + 1e-9, 'Average {} weights must be less than ' \
                'or equal to 1. Got {}.'.format(obj_name, sum(weights))
            unity_weights = [w / total_weight for w in weights]

        return weights, unity_weights

    @staticmethod
    def _average_schedule(name, scheds, weights, timestep):
        """Average a set of schedules together (no matter their type)."""
        try:
            return ScheduleRuleset.average_schedules(name, scheds, weights, timestep)
        except AttributeError:
            return ScheduleFixedInterval.average_schedules(name, scheds, weights)

    @staticmethod
    def _get_schedule_from_dict(sch_dict):
        """Get a schedule object from a schedule dictionary."""
        if sch_dict['type'] == 'ScheduleRuleset':
            return ScheduleRuleset.from_dict(sch_dict)
        elif sch_dict['type'] == 'ScheduleFixedInterval':
            return ScheduleFixedInterval.from_dict(sch_dict)
        else:
            raise NotImplementedError(
                'Schedule {} is not supported.'.format(sch_dict['type']))

    def __copy__(self):
        return _LoadBase(self.name)

    def ToString(self):
        """Overwrite .NET ToString."""
        return self.__repr__()

    def __repr__(self):
        return 'Load Base:\n name: {}'.format(self.name)
